@@ -137,13 +137,14 @@ void Event::setDtEnd(const KDateTime &dtEnd)
         return;
     }
 
-    update();
-
-    d->mDtEnd = dtEnd;
-    d->mMultiDayValid = false;
-    setHasDuration(!dtEnd.isValid());
-    setFieldDirty(FieldDtEnd);
-    updated();
+    if (d->mDtEnd != dtEnd || hasDuration() == dtEnd.isValid()) {
+        update();
+        d->mDtEnd = dtEnd;
+        d->mMultiDayValid = false;
+        setHasDuration(!dtEnd.isValid());
+        setFieldDirty(FieldDtEnd);
+        updated();
+    }
 }
 
 KDateTime Event::dtEnd() const
@@ -205,7 +206,7 @@ bool Event::isMultiDay(const KDateTime::Spec &spec) const
     // End date is non inclusive
     // If we have an incidence that duration is one day and ends with a start of a new day
     // than it is not a multiday event
-    if (multi && end.time() != QTime(0,0,0)) {
+    if (multi && end.time() != QTime(0, 0, 0)) {
         multi = start.daysTo(end) > 1;
     }
 
